summaryrefslogtreecommitdiff
path: root/chiselFrontend/src/main/scala/chisel3/core/Data.scala
diff options
context:
space:
mode:
authorJack Koenig2017-01-20 12:37:40 -0800
committerGitHub2017-01-20 12:37:40 -0800
commit2e6444cc55b54b59f781a14823e219d9a2413f72 (patch)
tree0affb83730db42e41df214e8095d1ff1dd02b162 /chiselFrontend/src/main/scala/chisel3/core/Data.scala
parent4512aeeacf594349cf9a816384e92bf3da63892f (diff)
Add Record as new superclass of Bundle (#366)
Record gives uses the power to create collections of heterogenous elements. Bundle is a special case of Record that uses reflection to populate the elements of the collection. Bundle also attempts to implement cloneType whereas users of Record are required to supply one.
Diffstat (limited to 'chiselFrontend/src/main/scala/chisel3/core/Data.scala')
-rw-r--r--chiselFrontend/src/main/scala/chisel3/core/Data.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/chiselFrontend/src/main/scala/chisel3/core/Data.scala b/chiselFrontend/src/main/scala/chisel3/core/Data.scala
index 6e80f045..4f3e2268 100644
--- a/chiselFrontend/src/main/scala/chisel3/core/Data.scala
+++ b/chiselFrontend/src/main/scala/chisel3/core/Data.scala
@@ -66,7 +66,7 @@ object Data {
* Note that the current scheme only applies Flip to Elements or Vec chains of
* Elements.
*
* A Bundle is never marked flip, instead preferring its root fields to be marked
*
* The Vec check is due to the fact that flip must be factored out of the vec, ie:
* must have flip field: Vec(UInt) instead of field: Vec(flip UInt)
@@ -74,7 +74,7 @@ object Data {
private[chisel3] def isFlipped(target: Data): Boolean = target match {
case (element: Element) => element.binding.direction == Some(Direction.Input)
case (vec: Vec[Data @unchecked]) => isFlipped(vec.sample_element)
- case (bundle: Bundle) => false
+ case (record: Record) => false
}
/** This function returns the "firrtl" flipped-ness for the specified object.
@@ -66,7 +66,7 @@ object Data {
* Elements.
*
- * A Bundle is never marked flip, instead preferring its root fields to be marked
+ * A Record is never marked flip, instead preferring its root fields to be marked
*
* The Vec check is due to the fact that flip must be factored out of the vec, ie: